@@ -1,7 +1,16 @@
 """Top-level package for PyGeoUtils."""
-from .exceptions import EmptyResponse, InvalidInputType, InvalidInputValue, MissingAttribute
+from .exceptions import (
+    EmptyResponse,
+    InvalidInputRange,
+    InvalidInputType,
+    InvalidInputValue,
+    MissingAttribute,
+    MissingCRS,
+)
 from .print_versions import show_versions
 from .pygeoutils import (
+    Coordinates,
+    GeoBSpline,
     arcgis2geojson,
     geo2polygon,
     get_gtiff_attrs,
@@ -11,6 +20,7 @@ from .pygeoutils import (
     xarray2geodf,
     xarray_geomask,
 )
+from .utils import transform2tuple
 
 try:
     import importlib.metadata as metadata
@@ -30,10 +40,15 @@ __all__ = [
     "gtiff2xarray",
     "xarray2geodf",
     "json2geodf",
+    "transform2tuple",
     "xarray_geomask",
+    "Coordinates",
+    "GeoBSpline",
     "InvalidInputType",
     "InvalidInputValue",
+    "InvalidInputRange",
     "MissingAttribute",
+    "MissingCRS",
     "EmptyResponse",
     "show_versions",
 ]
